/// <reference types="react" />
import { ILogger } from 'ts-smart-logger';
import { BaseTextField } from '../text-field/base-text-field.component';
import { EntityIdT, AnyT } from '../../../definitions.interface';
import { MultiFieldPlugin } from '../multifield/multifield.plugin';
import { IBaseEvent, IBaseFileFieldProps, IBaseFileFieldState, IKeyboardEvent } from '../../../definition';
export declare class BaseFileField<TProps extends IBaseFileFieldProps, TState extends IBaseFileFieldState> extends BaseTextField<TProps, TState> {
    static readonly defaultProps: IBaseFileFieldProps & Partial<import("../../../definition").IGenericComponentProps<any>>;
    protected static readonly logger: ILogger;
    protected readonly multiFieldPlugin: MultiFieldPlugin;
    private readonly cameraRef;
    private readonly cameraDialogRef;
    private readonly dndRef;
    /**
     * @stable [30.10.2019]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [28.06.2018]
     * @param {IBaseEvent} event
     */
    onKeyEnter(event: IBaseEvent): void;
    /**
     * @stable [28.06.2018]
     * @param {IKeyboardEvent} event
     */
    onKeyBackspace(event: IKeyboardEvent): void;
    clearValue(): void;
    /**
     * @stable [28.06.2018]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [03.08.2018]
     * @returns {JSX.Element}
     */
    protected get attachmentBodyElement(): JSX.Element;
    /**
     * @stable [02.08.2018]
     * @returns {EntityIdT[]}
     */
    protected get originalEmptyValue(): EntityIdT[];
    /**
     * @stable [05.10.2018]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [14.01.2019]
     * @param {AnyT} value
     * @returns {string}
     */
    protected decorateDisplayValue(value: AnyT): string;
    /**
     * @stable [11.05.2020]
     */
    private onCameraDialogDeactivate;
    /**
     * @stable [11.05.2020]
     */
    private onCameraDialogAccept;
    /**
     * @stable [19.12.2018]
     * @param {Blob[]} file
     */
    private onSelect;
    /**
     * @stable [02.08.2018]
     * @param {Blob} blob
     */
    private doSelectBlob;
    /**
     * @stable [01.08.2019]
     * @param {Blob} blob
     */
    private onCameraSnapshotSelect;
    private get dnd();
    /**
     * @stable [02.08.2018]
     * @param {IBaseEvent} event
     */
    private openCameraDialog;
    /**
     * @stable [28.06.2018]
     * @param {IBaseEvent} event
     */
    private openFileDialog;
    /**
     * @stable [28.06.2018]
     * @param {IBaseEvent} event
     */
    private downloadFile;
    /**
     * @stable [15.02.2020]
     * @returns {Dialog}
     */
    private get cameraDialog();
    /**
     * @stable [14.02.2020]
     * @returns {WebCamera}
     */
    private get camera();
    /**
     * @stable [30.10.2019]
     * @returns {boolean}
     */
    private get isDownloadActionDisabled();
}
