import { AnyT, EntityIdT, IEntity, IKeyValue } from '../../../definitions.interface';
import { IMultiFieldChangesEntity } from './multifield.interface';
import { IMultiItemEntity, MultiFieldValueT, MultiFieldSingleValueT } from '../../../definition';
/**
 * @stable [29.07.2019]
 * @param {MultiFieldSingleValueT} multiFieldEntity
 * @returns {EntityIdT}
 */
export declare const toLastAddedMultiItemEntityId: (multiFieldEntity: MultiFieldSingleValueT) => EntityIdT;
/**
 * @stable [04.07.2018]
 * @param {MultiFieldValueT} multiFieldEntity
 * @returns {EntityIdT[]}
 */
export declare const fromMultiFieldEntityToEditedEntitiesIds: (multiFieldEntity: MultiFieldValueT) => EntityIdT[];
/**
 * @stable [18.08.2018]
 * @param {MultiFieldValueT} multiFieldValue
 * @param {(entity: TItem, index: number) => TResult} mapper
 * @returns {TResult[]}
 */
export declare function fromMultiFieldValueToEditedEntities<TItem extends IEntity = IEntity, TResult = IEntity>(multiFieldValue: MultiFieldValueT<TItem>, mapper: (entity: TItem, index: number) => TResult): TResult[];
/**
 * @stable [02.07.2018]
 * @param {MultiFieldValueT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IEntity[]}
 */
export declare const extractMultiAddItemEntities: (value: MultiFieldValueT, defaultValue?: IMultiItemEntity[]) => IEntity[];
/**
 * @stable [23.06.2018]
 * @param {MultiFieldValueT} value
 * @param {IEntity[]} defaultValue
 * @returns {IEntity[]}
 */
export declare const extractMultiSourceItemEntities: (value: MultiFieldValueT, defaultValue?: IEntity[]) => IEntity[];
/**
 * @stable [02.07.2018]
 * @param {IEntity | IMultiItemEntity} entity
 * @returns {IEntity}
 */
export declare const fromMultiItemEntityToEntity: (entity: IEntity | IMultiItemEntity) => IEntity;
/**
 * @stable [23.06.2018]
 * @param {string} fieldName
 * @param {MultiFieldValueT} multiFieldValue
 * @param {(itm: IMultiItemEntity) => boolean} predicate
 * @param {(itm: IMultiItemEntity) => AnyT} nextFieldValueFn
 * @returns {IMultiItemEntity}
 */
export declare const buildMultiEditItemEntityPayload: <TEntity extends IEntity = IEntity>(fieldName: string, multiFieldValue: MultiFieldValueT, predicate: (itm: IMultiItemEntity) => boolean, nextFieldValueFn: (multiItemEntity: IMultiItemEntity, entity: TEntity) => AnyT) => IMultiItemEntity;
/**
 * @stable [04.07.2018]
 * @param {IMultiItemEntity[]} multiItemEntities
 * @returns {IKeyValue}
 */
export declare const fromMultiItemEntitiesToFieldsChanges: (multiItemEntities: IMultiItemEntity[]) => IKeyValue;
/**
 * @stable [11.08.2018]
 * @param {IMultiItemEntity} first
 * @param {IMultiItemEntity} second
 * @returns {boolean}
 */
export declare const isSameEntityByIdAndChangedFieldName: (first: IMultiItemEntity, second: IMultiItemEntity) => boolean;
/**
 * @stable [11.08.2018]
 * @param {IMultiItemEntity} item
 * @param {IEntity[]} addValue
 * @param {IMultiItemEntity[]} removeValue
 * @param {IMultiItemEntity[]} editValue
 * @param {IEntity[]} originalValue
 * @returns {IMultiFieldChangesEntity}
 */
export declare const toMultiFieldChangesEntityOnEdit: (item: IMultiItemEntity, addValue: IEntity[], removeValue: IMultiItemEntity[], editValue: IMultiItemEntity[], originalValue: IEntity[]) => IMultiFieldChangesEntity;
/**
 * @stable [18.08.2018]
 * @param {IMultiItemEntity} item
 * @param {IEntity[]} addValue
 * @param {IMultiItemEntity[]} removeValue
 * @param {IMultiItemEntity[]} editValue
 * @param {IEntity[]} originalValue
 * @returns {IMultiFieldChangesEntity}
 */
export declare const toMultiFieldChangesEntityOnDelete: (item: IMultiItemEntity, addValue: IEntity[], removeValue: IMultiItemEntity[], editValue: IMultiItemEntity[], originalValue: IEntity[]) => IMultiFieldChangesEntity;
