"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.asExpandedGridGroups = exports.filterAndSortGridOriginalDataSource = exports.getGridColumnSortDirection = exports.buildTimeGridColumns = exports.buildTimeGridInfoColumn = exports.DEFAULT_BUILDER_CONFIG = void 0;
var R = require("ramda");
var util_1 = require("../../util");
var definitions_interface_1 = require("../../definitions.interface");
var MINUTES_PER_HOUR = 60;
var HOURS_PER_DAY = 24;
var HOURS_PER_HALF_OF_DAY = HOURS_PER_DAY / 2;
var RANGE_SEPARATOR = " " + definitions_interface_1.UNI_CODES.nDash + " ";
/**
 * @stable [10.09.2018]
 */
exports.DEFAULT_BUILDER_CONFIG = {
    hourFrom: 0,
    hourTo: 23,
    cellWidthFactor: 1.2,
    minPeriodAtMinutes: 10,
    timeAbbreviationResolver: function (isBeforeNoon) { return isBeforeNoon ? 'am' : 'pm'; },
    timeResolver: function (hour, isBeforeNoon) { return isBeforeNoon ? hour : hour - HOURS_PER_HALF_OF_DAY; },
};
/**
 * @stable [04.10.2018]
 * @param {IGridColumnProps} defaultConfig
 * @param {string} extraClassName
 * @returns {IGridColumnProps}
 */
exports.buildTimeGridInfoColumn = function (defaultConfig, extraClassName) {
    return (__assign(__assign({}, defaultConfig), { columnClassName: function (props) { return util_1.toClassName(extraClassName, util_1.calc(defaultConfig.columnClassName, props)); } }));
};
/**
 * @stable [13.09.2018]
 * @param {number} hour
 * @param {number} minutes
 * @param {ITimeGridBuilderConfigEntity} builderConfig
 * @returns {IGridColumnProps}
 */
var toUsaTime = function (hour, minutes, builderConfig) {
    var isBeforeNoon = hour < HOURS_PER_HALF_OF_DAY;
    var timeResolver = builderConfig.timeResolver;
    var timeAbbreviationResolver = builderConfig.timeAbbreviationResolver;
    var timeAbbreviation = timeAbbreviationResolver(isBeforeNoon) || '';
    var isUsaTimeAbbreviation = timeAbbreviation.length > 0;
    var localHour = timeResolver(hour, isBeforeNoon);
    var normalizedLocalHour = localHour === HOURS_PER_DAY && !isUsaTimeAbbreviation ? '00' : localHour;
    var normalizedMinutes = util_1.normalizeTime(String(minutes));
    var normalizedHour = util_1.normalizeTime(String(hour));
    return {
        name: normalizedHour + ":" + normalizedMinutes,
        title: util_1.join([normalizedLocalHour, timeAbbreviation], ' '),
        columnTitle: util_1.join([normalizedLocalHour + ":" + normalizedMinutes, timeAbbreviation], ' '),
    };
};
/**
 * @stable [10.09.2018]
 * @param {IGridColumnProps} defaultConfig
 * @param {ITimeGridBuilderConfigEntity} builderConfig
 * @returns {IGridColumnProps[]}
 */
exports.buildTimeGridColumns = function (defaultConfig, builderConfig) {
    builderConfig = __assign(__assign({}, exports.DEFAULT_BUILDER_CONFIG), builderConfig);
    var cellWidthFactor = builderConfig.cellWidthFactor;
    var periodsPerHourCount = MINUTES_PER_HOUR / builderConfig.minPeriodAtMinutes;
    var periodsCount = Math.max(periodsPerHourCount, 1);
    var columnsCount = periodsPerHourCount * HOURS_PER_DAY;
    var currentPeriodPerHour = 0;
    return util_1.makeArray(columnsCount)
        .map(function (_, index) {
        var minPeriodAtMinutes = builderConfig.minPeriodAtMinutes;
        var currentHour = Math.floor(index / periodsPerHourCount);
        var ceilWidth = Math.floor(minPeriodAtMinutes / cellWidthFactor);
        var currentMinutes = currentPeriodPerHour * minPeriodAtMinutes;
        var columnClassName = util_1.toClassName(currentPeriodPerHour === periodsPerHourCount - 1 && 'rac-time-grid-bordered-column', 'rac-time-grid-column');
        var tillTime = currentHour * MINUTES_PER_HOUR + minPeriodAtMinutes;
        var tillHour = Math.floor(tillTime / MINUTES_PER_HOUR);
        var tillMinutes = tillTime - tillHour * MINUTES_PER_HOUR;
        var isSameHour = tillHour - currentHour <= 1;
        var currentUsaTime = toUsaTime(currentHour, currentMinutes, builderConfig);
        var tillUsaTime = toUsaTime(tillHour, tillMinutes, builderConfig);
        var item = util_1.defValuesFilter(__assign(__assign(__assign({ align: 'center', headerClassName: 'rac-time-grid-time-header-column', title: isSameHour
                ? currentUsaTime.title
                : util_1.join([currentUsaTime.title, tillUsaTime.title], RANGE_SEPARATOR), width: ceilWidth, headerRendered: currentPeriodPerHour === 0, headerWidth: ceilWidth * periodsCount, headerColSpan: util_1.orUndef(currentPeriodPerHour === 0, periodsCount), columnTitle: isSameHour
                ? currentUsaTime.columnTitle
                : util_1.join([currentUsaTime.columnTitle, tillUsaTime.columnTitle], RANGE_SEPARATOR), tpl: function () { return definitions_interface_1.UNI_CODES.noBreakSpace; } }, defaultConfig), exports.buildTimeGridInfoColumn({ columnClassName: defaultConfig.columnClassName }, columnClassName)), { name: currentUsaTime.name }));
        currentPeriodPerHour = ++currentPeriodPerHour === periodsCount ? 0 : currentPeriodPerHour;
        return util_1.orNull(builderConfig.hourFrom <= currentHour && currentHour <= builderConfig.hourTo, item);
    })
        .filter(function (item) { return !R.isNil(item); });
};
/**
 * @stable [12.02.2019]
 * @param {IGridColumnProps} column
 * @param {IGridProps} props
 * @returns {SortDirectionsEnum}
 */
exports.getGridColumnSortDirection = function (column, props) {
    return props.directions[column.name];
};
// TODO Refactoring
exports.filterAndSortGridOriginalDataSource = function (source, columns, props, state) {
    if (R.isNil(source)) {
        return source;
    }
    if (props.localSorting) {
        var sorters = columns
            .filter(function (column) { return util_1.isFn(column.sorter) && !R.isNil(exports.getGridColumnSortDirection(column, props).direction); })
            .map(function (column) { return function (entity1, entity2) {
            return column.sorter(entity1, entity2) * (exports.getGridColumnSortDirection(column, props).direction === 0 ? 1 : -1);
        }; });
        if (sorters.length > 0) {
            source = R.sortWith(sorters, source);
        }
    }
    if (props.localFiltration) {
        var filterChanges_1 = state.filterChanges;
        var changedColumns_1 = Object.keys(filterChanges_1);
        var defaultLocalFilter_1 = function (cfg) {
            return util_1.FilterUtils.queryFilter(cfg.query, cfg.entity[cfg.columnName]);
        };
        if (changedColumns_1.length > 0) {
            source = source.filter(function (entity) {
                var result = true;
                changedColumns_1.forEach(function (columnName) {
                    var query = filterChanges_1[columnName];
                    var column = columns.find(function (column0) { return column0.name === columnName; });
                    if (!R.isNil(column)) {
                        var localFilter = column.localFilter;
                        result = result && (util_1.isFn(localFilter) ? localFilter : defaultLocalFilter_1)({ query: query, columnName: columnName, entity: entity });
                    }
                });
                return result;
            });
        }
    }
    return source;
};
/**
 * @stable [29.12.2019]
 * @param {MultiFieldValueT<TEntity extends IEntity>} entity
 * @param {(item: TEntity) => EntityIdT} groupValueAccessor
 * @returns {Record<EntityIdT, boolean>}
 */
exports.asExpandedGridGroups = function (entity, groupValueAccessor) {
    if (groupValueAccessor === void 0) { groupValueAccessor = function (item) { return item.id; }; }
    return R.mergeAll((util_1.MultiFieldUtils.multiFieldValueAsEntities(entity) || [])
        .map(function (item) {
        var _a;
        return (_a = {}, _a[groupValueAccessor(item)] = true, _a);
    }));
};
//# sourceMappingURL=grid.support.js.map