"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterUtils = exports.findByType = exports.filterAndSortEntities = exports.excludeIdFieldFilter = exports.notNilValuesFilter = exports.defValuesFilter = exports.excludeFieldsFilter = exports.stringValuesArrayFilter = exports.trueValuesArrayFilter = exports.TRUE_VALUE_PREDICATE = exports.SAME_ENTITY_PREDICATE = void 0;
var R = require("ramda");
var field_definition_interface_1 = require("../definition/field-definition.interface");
var type_1 = require("./type");
var object_1 = require("./object");
/**
 * @stable [29.08.2020]
 * @param source
 * @param predicates
 */
var cloneByFilters = function (source) {
    var predicates = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        predicates[_i - 1] = arguments[_i];
    }
    var sourceWithObjectValues = filterByPredicate.apply(void 0, __spreadArrays([source], predicates.concat(OBJECT_KEY_VALUE_PREDICATE)));
    var sourceWithoutObjectValue = filterByPredicate.apply(void 0, __spreadArrays([source], predicates.concat(NOT_OBJECT_KEY_VALUE_PREDICATE)));
    var result = __assign({}, sourceWithoutObjectValue);
    Object
        .keys(sourceWithObjectValues)
        .forEach(function (key) { return (result[key] = cloneByFilters.apply(void 0, __spreadArrays([sourceWithObjectValues[key]], predicates))); });
    return result;
};
/**
 * @stable [29.08.2020]
 * @param source
 * @param predicates
 */
var filterByPredicate = function (source) {
    var predicates = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        predicates[_i - 1] = arguments[_i];
    }
    return R.pickBy(function (value, key) { return predicates.length > 1
        ? predicates
            .reduce(function (prevValue, curValue) {
            return curValue(key, value) && (type_1.TypeUtils.isFn(prevValue)
                ? prevValue(key, value)
                : prevValue);
        })
        : predicates[0](key, value); }, source);
};
/**
 * @stable [15.05.2020]
 * @param {string} fields
 * @returns {(key: string, value: AnyT) => boolean}
 */
var excludeFieldsPredicateFactory = function () {
    var fields = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        fields[_i] = arguments[_i];
    }
    return function (key) { return !fields.includes(key); };
};
/**
 * @stable [15.05.2020]
 */
var EXCLUDE_ID_FIELD_PREDICATE = excludeFieldsPredicateFactory(field_definition_interface_1.FieldConstants.ID_FIELD_NAME);
/**
 * @stable [15.05.2020]
 */
var EXCLUDE_ENTITY_ID_FIELD_PREDICATE = excludeFieldsPredicateFactory(field_definition_interface_1.FieldConstants.ENTITY_ID_FIELD_NAME);
/**
 * @stable [09.01.2019]
 * @param {IEntity} entity1
 * @param {IEntity} entity2
 */
exports.SAME_ENTITY_PREDICATE = function (entity1, entity2) {
    return entity1 === entity2 || (!R.isNil(entity1) && !R.isNil(entity2) && entity1.id === entity2.id);
};
/**
 * @stable [29.08.2020]
 * @param value
 * @constructor
 */
var OBJECT_VALUE_PREDICATE = function (value) { return type_1.TypeUtils.isObject(value); };
/**
 * @stable [29.08.2020]
 * @param value
 */
var EVENT_VALUE_PREDICATE = function (value) { return type_1.TypeUtils.isEvent(value); };
/**
 * @stable [29.08.2020]
 * @param key
 * @param value
 */
var OBJECT_KEY_VALUE_PREDICATE = function (key, value) { return OBJECT_VALUE_PREDICATE(value); };
/**
 * @stable [29.08.2020]
 * @param value
 */
var NOT_OBJECT_VALUE_PREDICATE = function (value) { return !OBJECT_VALUE_PREDICATE(value); };
/**
 * @stable [29.08.2020]
 * @param key
 * @param value
 */
var NOT_OBJECT_KEY_VALUE_PREDICATE = function (key, value) { return NOT_OBJECT_VALUE_PREDICATE(value); };
/**
 * @stable [28.09.2020]
 * @param value
 */
var NOT_NIL_VALUE_PREDICATE = function (value) { return !R.isNil(value); };
/**
 * @stable [28.09.2020]
 * @param value
 */
var NIL_VALUE_PREDICATE = function (value) { return R.isNil(value); };
/**
 * @stable [28.09.2020]
 * @param key
 * @param value
 */
var NOT_NIL_KEY_VALUE_PREDICATE = function (key, value) { return NOT_NIL_VALUE_PREDICATE(value); };
/**
 * @stable [28.09.2020]
 * @param key
 * @param value
 */
var NIL_KEY_VALUE_PREDICATE = function (key, value) { return NIL_VALUE_PREDICATE(value); };
/**
 * @stable [20.05.2020]
 * @param {AnyT} value
 * @returns {boolean}
 */
var STRING_VALUE_PREDICATE = function (value) { return type_1.TypeUtils.isString(value); };
/**
 * @stable [17.05.2020]
 * @param {AnyT} value
 * @returns {boolean}
 */
var NOT_EMPTY_VALUE_PREDICATE = function (value) { return object_1.isObjectNotEmpty(value); };
/**
 * @stable [27.07.2020]
 * @param key
 * @param value
 */
var DEF_KEY_VALUE_PREDICATE = function (key, value) { return type_1.TypeUtils.isDef(value); };
/**
 * @stable [28.07.2020]
 * @param key
 * @param value
 */
var POSITIVE_OR_NEGATIVE_NUMBER_LIKE_KEY_VALUE_PREDICATE = function (key, value) { return type_1.TypeUtils.isPositiveOrNegativeNumberLike(value); };
/**
 * @stable [24.07.2020]
 * @param key
 * @param value
 */
var NOT_EMPTY_KEY_VALUE_PREDICATE = function (key, value) { return NOT_EMPTY_VALUE_PREDICATE(value); };
/**
 * @stable [16.05.2020]
 * @param {AnyT} value
 * @returns {boolean}
 */
var DEF_VALUE_PREDICATE = function (value) { return type_1.TypeUtils.isDef(value); };
/**
 * @stable [22.10.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.TRUE_VALUE_PREDICATE = function (value) { return value === true; };
/**
 * @stable [18.05.2020]
 * @param {TValue[]} data
 * @param {ValuePredicateT} predicates
 * @returns {TValue[]}
 */
var filterArray = function (data) {
    var predicates = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        predicates[_i - 1] = arguments[_i];
    }
    return R.filter(function (value) { return predicates.length > 1
        ? predicates
            .reduce(function (prevValue, curValue) { return (curValue(value) && (type_1.TypeUtils.isFn(prevValue)
            ? prevValue(value)
            : prevValue)); })
        : predicates[0](value); }, data);
};
/**
 * @stable [19.05.2020]
 * @param {TValue} data
 * @returns {TValue[]}
 */
var objectValuesArrayFilter = function () {
    var data = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        data[_i] = arguments[_i];
    }
    return filterArray(data, OBJECT_VALUE_PREDICATE);
};
/**
 * @stable [16.05.2020]
 * @param {TValue} data
 * @returns {TValue[]}
 */
var defValuesArrayFilter = function () {
    var data = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        data[_i] = arguments[_i];
    }
    return filterArray(data, DEF_VALUE_PREDICATE);
};
/**
 * @stable [18.05.2020]
 * @param {TValue} data
 * @returns {TValue[]}
 */
var notNilValuesArrayFilter = function () {
    var data = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        data[_i] = arguments[_i];
    }
    return filterArray(data, NOT_NIL_VALUE_PREDICATE);
};
/**
 * @stable [17.05.2020]
 * @param {TValue} data
 * @returns {TValue[]}
 */
var notEmptyValuesArrayFilter = function () {
    var data = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        data[_i] = arguments[_i];
    }
    return filterArray(data, NOT_EMPTY_VALUE_PREDICATE);
};
/**
 * @stable [22.10.2019]
 * @param {TValue} data
 * @returns {TValue[]}
 */
exports.trueValuesArrayFilter = function () {
    var data = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        data[_i] = arguments[_i];
    }
    return filterArray(data, exports.TRUE_VALUE_PREDICATE);
};
/**
 * @stable [25.12.2019]
 * @param {TValue} data
 * @returns {TValue[]}
 */
exports.stringValuesArrayFilter = function () {
    var data = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        data[_i] = arguments[_i];
    }
    return filterArray(data, STRING_VALUE_PREDICATE);
};
function excludeFieldsFilter(source) {
    var fields = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        fields[_i - 1] = arguments[_i];
    }
    return filterByPredicate(source, excludeFieldsPredicateFactory.apply(void 0, fields));
}
exports.excludeFieldsFilter = excludeFieldsFilter;
/**
 * @stable [27.07.2020]
 * @param source
 */
exports.defValuesFilter = function (source) {
    return filterByPredicate(source, DEF_KEY_VALUE_PREDICATE);
};
/**
 * @stable [28.07.2020]
 * @param source
 */
var positiveOrNegativeNumberLikeValuesFilter = function (source) {
    return filterByPredicate(source, POSITIVE_OR_NEGATIVE_NUMBER_LIKE_KEY_VALUE_PREDICATE);
};
/**
 * @stable [31.01.2019]
 * @param {TSource} source
 * @returns {TResult}
 */
exports.notNilValuesFilter = function (source) {
    return filterByPredicate(source, NOT_NIL_KEY_VALUE_PREDICATE);
};
/**
 * @stable [28.09.2020]
 * @param source
 */
var nilValuesFilter = function (source) {
    return filterByPredicate(source, NIL_KEY_VALUE_PREDICATE);
};
/**
 * @stable [08.05.2020]
 * @param {TSource} source
 * @returns {TResult}
 */
var notEmptyValuesFilter = function (source) {
    return filterByPredicate(source, NOT_EMPTY_KEY_VALUE_PREDICATE);
};
exports.excludeIdFieldFilter = function (source) {
    return filterByPredicate(source, EXCLUDE_ID_FIELD_PREDICATE);
};
/**
 * @stable [16.06.2018]
 * @param {TEntity[] | TEntity} data
 * @param {IFilterAndSorterConfiguration} config
 * @returns {TEntity[]}
 */
exports.filterAndSortEntities = function (data, config) {
    if (R.isNil(data)) {
        return data;
    }
    var entities = [].concat(data);
    if (!R.isNil(config)) {
        if (!R.isNil(config.filter)) {
            entities = R.filter(config.filter, entities);
        }
        if (!R.isNil(config.sorter)) {
            entities = R.sort(config.sorter, entities);
        }
    }
    return entities;
};
/**
 * @stable [06.04.2020]
 * @param {TValue[]} data
 * @param {TType} type
 * @returns {TValue}
 */
exports.findByType = function (data, type) {
    return data.find(function (itm) { return itm.type === type; });
};
/**
 * @stable [09.08.2020]
 * @param query
 * @param items
 */
var queryFilter = function (query) {
    var items = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        items[_i - 1] = arguments[_i];
    }
    if (!object_1.ObjectUtils.isObjectNotEmpty(query)) {
        return true;
    }
    var result = false;
    items
        .map(function (item) { return (type_1.TypeUtils.isString(item)
        ? item
        : R.isNil(item) ? '' : String(item)).toUpperCase(); })
        .forEach(function (v) { return result = result || v.includes(query.toUpperCase()); });
    return result;
};
/**
 * @stable [15.05.2020]
 */
var FilterUtils = /** @class */ (function () {
    function FilterUtils() {
    }
    FilterUtils.cloneByFilters = cloneByFilters; /* @stable [29.08.2020] */
    FilterUtils.defValuesArrayFilter = defValuesArrayFilter; /* @stable [15.05.2020] */
    FilterUtils.defValuesFilter = exports.defValuesFilter; /* @stable [27.07.2020] */
    FilterUtils.EVENT_VALUE_PREDICATE = EVENT_VALUE_PREDICATE; /* @stable [29.08.2020] */
    FilterUtils.EXCLUDE_ENTITY_ID_FIELD_PREDICATE = EXCLUDE_ENTITY_ID_FIELD_PREDICATE; /* @stable [15.05.2020] */
    FilterUtils.excludeFieldsPredicateFactory = excludeFieldsPredicateFactory; /* @stable [15.05.2020] */
    FilterUtils.filterByPredicate = filterByPredicate; /* @stable [29.08.2020] */
    FilterUtils.nilValuesFilter = nilValuesFilter; /* @stable [28.09.2020] */
    FilterUtils.NOT_NIL_VALUE_PREDICATE = NOT_NIL_VALUE_PREDICATE; /* @stable [18.05.2020] */
    FilterUtils.notEmptyValuesArrayFilter = notEmptyValuesArrayFilter; /* @stable [17.05.2020] */
    FilterUtils.notEmptyValuesFilter = notEmptyValuesFilter; /* @stable [24.07.2020] */
    FilterUtils.notNilValuesArrayFilter = notNilValuesArrayFilter; /* @stable [18.05.2020] */
    FilterUtils.notNilValuesFilter = exports.notNilValuesFilter; /* @stable [21.06.2020] */
    FilterUtils.OBJECT_VALUE_PREDICATE = OBJECT_VALUE_PREDICATE; /* @stable [19.05.2020] */
    FilterUtils.objectValuesArrayFilter = objectValuesArrayFilter; /* @stable [19.05.2020] */
    FilterUtils.positiveOrNegativeNumberLikeValuesFilter = positiveOrNegativeNumberLikeValuesFilter; /* @stable [28.07.2020] */
    FilterUtils.queryFilter = queryFilter; /* @stable [03.08.2020] */
    FilterUtils.SAME_ENTITY_PREDICATE = exports.SAME_ENTITY_PREDICATE; /* @stable [10.06.2020] */
    FilterUtils.STRING_VALUE_PREDICATE = STRING_VALUE_PREDICATE; /* @stable [20.05.2020] */
    return FilterUtils;
}());
exports.FilterUtils = FilterUtils;
//# sourceMappingURL=filter.js.map